#
# Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
# Copyright (c) 2018-2022 The Uncertainty Quantification Foundation.
# License: 3-clause BSD.  The full license text is available at:
#  - https://github.com/uqfoundation/pathos/blob/master/LICENSE

from pathos.portpicker import portnumber, __doc__


if __name__ == '__main__':

    pick = portnumber(min=1024,max=65535)
    print( pick() )

